==> cost-interface-0.3.0-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/regist/CountryPlaneAdRegistVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.regist;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告登记
 * CountryPlaneAdRegist
 * 数据库表：country_plane_ad_regist
 */
public class CountryPlaneAdRegistVo implements Serializable {

    private static final long serialVersionUID = -4924992358206895492L;
    /**
     * 
     * 表字段 : country_plane_ad_regist.id
     */
    private Integer id;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_regist.regist_no
     */
    private String registNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_regist.apply_no
     */
    private String applyNo;

    /**
     * 登记单行项目号
     */
    private Integer itemNo;

    /**
     * 申请单行项目号
     * 表字段 : country_plane_ad_regist.apply_item_no
     */
    private Integer applyItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_regist.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_regist.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_regist.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_regist.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_regist.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_regist.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_regist.media_content
     */
    private String mediaContent;

    /**
     * 开始日期
     * 表字段 : country_plane_ad_regist.s_date
     */
    private Date sDate;

    /**
     * 结束日期
     * 表字段 : country_plane_ad_regist.e_date
     */
    private Date eDate;

    /**
     * 推广品牌编码
     * 表字段 : country_plane_ad_regist.brand_id
     */
    private String brandId;

    /**
     * 推广品牌名称
     * 表字段 : country_plane_ad_regist.brand_name
     */
    private String brandName;

    /**
     * 数量
     * 表字段 : country_plane_ad_regist.count
     */
    private Integer count;

    /**
     * 实施方
     * 表字段 : country_plane_ad_regist.implementing_party
     */
    private String implementingParty;

    /**
     * 联系人
     * 表字段 : country_plane_ad_regist.contacts
     */
    private String contacts;

    /**
     * 联系方式
     * 表字段 : country_plane_ad_regist.contact_way
     */
    private String contactWay;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_regist.activity_forms
     */
    private String activityForms;

    /**
     * 厂方承担金额(分)
     * 表字段 : country_plane_ad_regist.company_amount
     */
    private Long companyAmount;

    /**
     * 备注
     * 表字段 : country_plane_ad_regist.notes
     */
    private String notes;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_regist.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_regist.audit_notes
     */
    private String auditNotes;

    /**
     * 
     * 表字段 : country_plane_ad_regist.create_id
     */
    private String createId;

    /**
     * 
     * 表字段 : country_plane_ad_regist.create_name
     */
    private String createName;

    /**
     * 
     * 表字段 : country_plane_ad_regist.create_date
     */
    private Date createDate;

    /**
     * 
     * 表字段 : country_plane_ad_regist.modify_id
     */
    private String modifyId;

    /**
     * 
     * 表字段 : country_plane_ad_regist.modify_name
     */
    private String modifyName;

    /**
     * 
     * 表字段 : country_plane_ad_regist.modify_date
     */
    private Date modifyDate;

    /**
     * 获取  字段:country_plane_ad_regist.id
     *
     * @return country_plane_ad_regist.id, 
     */
    public Integer getId() {
        return id;
    }

    /**
     * 设置  字段:country_plane_ad_regist.id
     *
     * @param id the value for country_plane_ad_regist.id, 
     */
    public void setId(Integer id) {
        this.id = id;
    }

    /**
     * 获取 登记单号 字段:country_plane_ad_regist.regist_no
     *
     * @return country_plane_ad_regist.regist_no, 登记单号
     */
    public String getRegistNo() {
        return registNo;
    }

    /**
     * 设置 登记单号 字段:country_plane_ad_regist.regist_no
     *
     * @param registNo the value for country_plane_ad_regist.regist_no, 登记单号
     */
    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    /**
     * 获取 申请单号 字段:country_plane_ad_regist.apply_no
     *
     * @return country_plane_ad_regist.apply_no, 申请单号
     */
    public String getApplyNo() {
        return applyNo;
    }

    /**
     * 设置 申请单号 字段:country_plane_ad_regist.apply_no
     *
     * @param applyNo the value for country_plane_ad_regist.apply_no, 申请单号
     */
    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    /**
     * 获取 申请单行项目号 字段:country_plane_ad_regist.apply_item_no
     *
     * @return country_plane_ad_regist.apply_item_no, 申请单行项目号
     */
    public Integer getApplyItemNo() {
        return applyItemNo;
    }

    /**
     * 设置 申请单行项目号 字段:country_plane_ad_regist.apply_item_no
     *
     * @param applyItemNo the value for country_plane_ad_regist.apply_item_no, 申请单行项目号
     */
    public void setApplyItemNo(Integer applyItemNo) {
        this.applyItemNo = applyItemNo;
    }

    /**
     * 获取 费用类型编码 字段:country_plane_ad_regist.cost_type_id
     *
     * @return country_plane_ad_regist.cost_type_id, 费用类型编码
     */
    public String getCostTypeId() {
        return costTypeId;
    }

    /**
     * 设置 费用类型编码 字段:country_plane_ad_regist.cost_type_id
     *
     * @param costTypeId the value for country_plane_ad_regist.cost_type_id, 费用类型编码
     */
    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    /**
     * 获取 费用类型名称 字段:country_plane_ad_regist.cost_type_name
     *
     * @return country_plane_ad_regist.cost_type_name, 费用类型名称
     */
    public String getCostTypeName() {
        return costTypeName;
    }

    /**
     * 设置 费用类型名称 字段:country_plane_ad_regist.cost_type_name
     *
     * @param costTypeName the value for country_plane_ad_regist.cost_type_name, 费用类型名称
     */
    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    /**
     * 获取 媒体大类 字段:country_plane_ad_regist.media_big_code
     *
     * @return country_plane_ad_regist.media_big_code, 媒体大类
     */
    public String getMediaBigCode() {
        return mediaBigCode;
    }

    /**
     * 设置 媒体大类 字段:country_plane_ad_regist.media_big_code
     *
     * @param mediaBigCode the value for country_plane_ad_regist.media_big_code, 媒体大类
     */
    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    /**
     * 获取 媒体大类名称 字段:country_plane_ad_regist.media_big_name
     *
     * @return country_plane_ad_regist.media_big_name, 媒体大类名称
     */
    public String getMediaBigName() {
        return mediaBigName;
    }

    /**
     * 设置 媒体大类名称 字段:country_plane_ad_regist.media_big_name
     *
     * @param mediaBigName the value for country_plane_ad_regist.media_big_name, 媒体大类名称
     */
    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    /**
     * 获取 媒体小类 字段:country_plane_ad_regist.media_small_code
     *
     * @return country_plane_ad_regist.media_small_code, 媒体小类
     */
    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    /**
     * 设置 媒体小类 字段:country_plane_ad_regist.media_small_code
     *
     * @param mediaSmallCode the value for country_plane_ad_regist.media_small_code, 媒体小类
     */
    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    /**
     * 获取 媒体小类名称 字段:country_plane_ad_regist.media_small_name
     *
     * @return country_plane_ad_regist.media_small_name, 媒体小类名称
     */
    public String getMediaSmallName() {
        return mediaSmallName;
    }

    /**
     * 设置 媒体小类名称 字段:country_plane_ad_regist.media_small_name
     *
     * @param mediaSmallName the value for country_plane_ad_regist.media_small_name, 媒体小类名称
     */
    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    /**
     * 获取 媒体内容 字段:country_plane_ad_regist.media_content
     *
     * @return country_plane_ad_regist.media_content, 媒体内容
     */
    public String getMediaContent() {
        return mediaContent;
    }

    /**
     * 设置 媒体内容 字段:country_plane_ad_regist.media_content
     *
     * @param mediaContent the value for country_plane_ad_regist.media_content, 媒体内容
     */
    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    /**
     * 获取 开始日期 字段:country_plane_ad_regist.s_date
     *
     * @return country_plane_ad_regist.s_date, 开始日期
     */
    public Date getsDate() {
        return sDate;
    }

    /**
     * 设置 开始日期 字段:country_plane_ad_regist.s_date
     *
     * @param sDate the value for country_plane_ad_regist.s_date, 开始日期
     */
    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    /**
     * 获取 结束日期 字段:country_plane_ad_regist.e_date
     *
     * @return country_plane_ad_regist.e_date, 结束日期
     */
    public Date geteDate() {
        return eDate;
    }

    /**
     * 设置 结束日期 字段:country_plane_ad_regist.e_date
     *
     * @param eDate the value for country_plane_ad_regist.e_date, 结束日期
     */
    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    /**
     * 获取 推广品牌编码 字段:country_plane_ad_regist.brand_id
     *
     * @return country_plane_ad_regist.brand_id, 推广品牌编码
     */
    public String getBrandId() {
        return brandId;
    }

    /**
     * 设置 推广品牌编码 字段:country_plane_ad_regist.brand_id
     *
     * @param brandId the value for country_plane_ad_regist.brand_id, 推广品牌编码
     */
    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    /**
     * 获取 推广品牌名称 字段:country_plane_ad_regist.brand_name
     *
     * @return country_plane_ad_regist.brand_name, 推广品牌名称
     */
    public String getBrandName() {
        return brandName;
    }

    /**
     * 设置 推广品牌名称 字段:country_plane_ad_regist.brand_name
     *
     * @param brandName the value for country_plane_ad_regist.brand_name, 推广品牌名称
     */
    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    /**
     * 获取 数量 字段:country_plane_ad_regist.count
     *
     * @return country_plane_ad_regist.count, 数量
     */
    public Integer getCount() {
        return count;
    }

    /**
     * 设置 数量 字段:country_plane_ad_regist.count
     *
     * @param count the value for country_plane_ad_regist.count, 数量
     */
    public void setCount(Integer count) {
        this.count = count;
    }

    /**
     * 获取 实施方 字段:country_plane_ad_regist.implementing_party
     *
     * @return country_plane_ad_regist.implementing_party, 实施方
     */
    public String getImplementingParty() {
        return implementingParty;
    }

    /**
     * 设置 实施方 字段:country_plane_ad_regist.implementing_party
     *
     * @param implementingParty the value for country_plane_ad_regist.implementing_party, 实施方
     */
    public void setImplementingParty(String implementingParty) {
        this.implementingParty = implementingParty;
    }

    /**
     * 获取 联系人 字段:country_plane_ad_regist.contacts
     *
     * @return country_plane_ad_regist.contacts, 联系人
     */
    public String getContacts() {
        return contacts;
    }

    /**
     * 设置 联系人 字段:country_plane_ad_regist.contacts
     *
     * @param contacts the value for country_plane_ad_regist.contacts, 联系人
     */
    public void setContacts(String contacts) {
        this.contacts = contacts;
    }

    /**
     * 获取 联系方式 字段:country_plane_ad_regist.contact_way
     *
     * @return country_plane_ad_regist.contact_way, 联系方式
     */
    public String getContactWay() {
        return contactWay;
    }

    /**
     * 设置 联系方式 字段:country_plane_ad_regist.contact_way
     *
     * @param contactWay the value for country_plane_ad_regist.contact_way, 联系方式
     */
    public void setContactWay(String contactWay) {
        this.contactWay = contactWay;
    }

    /**
     * 获取 活动形式 字段:country_plane_ad_regist.activity_forms
     *
     * @return country_plane_ad_regist.activity_forms, 活动形式
     */
    public String getActivityForms() {
        return activityForms;
    }

    /**
     * 设置 活动形式 字段:country_plane_ad_regist.activity_forms
     *
     * @param activityForms the value for country_plane_ad_regist.activity_forms, 活动形式
     */
    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    /**
     * 获取 厂方承担金额(分) 字段:country_plane_ad_regist.company_amount
     *
     * @return country_plane_ad_regist.company_amount, 厂方承担金额(分)
     */
    public Long getCompanyAmount() {
        return companyAmount;
    }

    /**
     * 设置 厂方承担金额(分) 字段:country_plane_ad_regist.company_amount
     *
     * @param companyAmount the value for country_plane_ad_regist.company_amount, 厂方承担金额(分)
     */
    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    /**
     * 获取 备注 字段:country_plane_ad_regist.notes
     *
     * @return country_plane_ad_regist.notes, 备注
     */
    public String getNotes() {
        return notes;
    }

    /**
     * 设置 备注 字段:country_plane_ad_regist.notes
     *
     * @param notes the value for country_plane_ad_regist.notes, 备注
     */
    public void setNotes(String notes) {
        this.notes = notes;
    }

    /**
     * 获取 行项目余额 字段:country_plane_ad_regist.item_balance
     *
     * @return country_plane_ad_regist.item_balance, 行项目余额
     */
    public Long getItemBalance() {
        return itemBalance;
    }

    /**
     * 设置 行项目余额 字段:country_plane_ad_regist.item_balance
     *
     * @param itemBalance the value for country_plane_ad_regist.item_balance, 行项目余额
     */
    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    /**
     * 获取 督查意见 字段:country_plane_ad_regist.audit_notes
     *
     * @return country_plane_ad_regist.audit_notes, 督查意见
     */
    public String getAuditNotes() {
        return auditNotes;
    }

    /**
     * 设置 督查意见 字段:country_plane_ad_regist.audit_notes
     *
     * @param auditNotes the value for country_plane_ad_regist.audit_notes, 督查意见
     */
    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    /**
     * 获取  字段:country_plane_ad_regist.create_id
     *
     * @return country_plane_ad_regist.create_id, 
     */
    public String getCreateId() {
        return createId;
    }

    /**
     * 设置  字段:country_plane_ad_regist.create_id
     *
     * @param createId the value for country_plane_ad_regist.create_id, 
     */
    public void setCreateId(String createId) {
        this.createId = createId;
    }

    /**
     * 获取  字段:country_plane_ad_regist.create_name
     *
     * @return country_plane_ad_regist.create_name, 
     */
    public String getCreateName() {
        return createName;
    }

    /**
     * 设置  字段:country_plane_ad_regist.create_name
     *
     * @param createName the value for country_plane_ad_regist.create_name, 
     */
    public void setCreateName(String createName) {
        this.createName = createName;
    }

    /**
     * 获取  字段:country_plane_ad_regist.create_date
     *
     * @return country_plane_ad_regist.create_date, 
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 设置  字段:country_plane_ad_regist.create_date
     *
     * @param createDate the value for country_plane_ad_regist.create_date, 
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 获取  字段:country_plane_ad_regist.modify_id
     *
     * @return country_plane_ad_regist.modify_id, 
     */
    public String getModifyId() {
        return modifyId;
    }

    /**
     * 设置  字段:country_plane_ad_regist.modify_id
     *
     * @param modifyId the value for country_plane_ad_regist.modify_id, 
     */
    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    /**
     * 获取  字段:country_plane_ad_regist.modify_name
     *
     * @return country_plane_ad_regist.modify_name, 
     */
    public String getModifyName() {
        return modifyName;
    }

    /**
     * 设置  字段:country_plane_ad_regist.modify_name
     *
     * @param modifyName the value for country_plane_ad_regist.modify_name, 
     */
    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    /**
     * 获取  字段:country_plane_ad_regist.modify_date
     *
     * @return country_plane_ad_regist.modify_date, 
     */
    public Date getModifyDate() {
        return modifyDate;
    }

    /**
     * 设置  字段:country_plane_ad_regist.modify_date
     *
     * @param modifyDate the value for country_plane_ad_regist.modify_date, 
     */
    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.6-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/regist/CountryPlaneAdRegistVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.regist;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告登记
 * CountryPlaneAdRegist
 * 数据库表：country_plane_ad_regist
 */
public class CountryPlaneAdRegistVo implements Serializable {

    private static final long serialVersionUID = -4924992358206895492L;
    /**
     *
     * 表字段 : country_plane_ad_regist.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_regist.item_no
     */
    private String itemNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_regist.regist_no
     */
    private String registNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_regist.apply_no
     */
    private String applyNo;

    /**
     * 申请单行项目号
     * 表字段 : country_plane_ad_regist.apply_item_no
     */
    private Integer applyItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_regist.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_regist.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_regist.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_regist.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_regist.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_regist.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_regist.media_content
     */
    private String mediaContent;

    /**
     * 开始日期
     * 表字段 : country_plane_ad_regist.s_date
     */
    private Date sDate;

    /**
     * 结束日期
     * 表字段 : country_plane_ad_regist.e_date
     */
    private Date eDate;

    /**
     * 推广品牌编码
     * 表字段 : country_plane_ad_regist.brand_id
     */
    private String brandId;

    /**
     * 推广品牌名称
     * 表字段 : country_plane_ad_regist.brand_name
     */
    private String brandName;

    /**
     * 数量
     * 表字段 : country_plane_ad_regist.count
     */
    private Integer count;

    /**
     * 实施方
     * 表字段 : country_plane_ad_regist.implementing_party
     */
    private String implementingParty;

    /**
     * 联系人
     * 表字段 : country_plane_ad_regist.contacts
     */
    private String contacts;

    /**
     * 联系方式
     * 表字段 : country_plane_ad_regist.contact_way
     */
    private String contactWay;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_regist.activity_forms
     */
    private String activityForms;

    /**
     * 厂方承担金额(分)
     * 表字段 : country_plane_ad_regist.company_amount
     */
    private Long companyAmount;

    /**
     * 备注
     * 表字段 : country_plane_ad_regist.notes
     */
    private String notes;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_regist.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_regist.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_date
     */
    private Date modifyDate;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getItemNo() {
        return itemNo;
    }

    public void setItemNo(String itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getApplyItemNo() {
        return applyItemNo;
    }

    public void setApplyItemNo(Integer applyItemNo) {
        this.applyItemNo = applyItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public String getBrandId() {
        return brandId;
    }

    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getImplementingParty() {
        return implementingParty;
    }

    public void setImplementingParty(String implementingParty) {
        this.implementingParty = implementingParty;
    }

    public String getContacts() {
        return contacts;
    }

    public void setContacts(String contacts) {
        this.contacts = contacts;
    }

    public String getContactWay() {
        return contactWay;
    }

    public void setContactWay(String contactWay) {
        this.contactWay = contactWay;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getCompanyAmount() {
        return companyAmount;
    }

    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
